@@ -20,18 +20,24 @@ import annotations.Area;
 import org.ovirt.api.metamodel.annotations.In;
 import org.ovirt.api.metamodel.annotations.Out;
 import org.ovirt.api.metamodel.annotations.Service;
-
 import services.externalhostproviders.KatelloErrataService;
 import types.Cluster;
 import types.Host;
 import types.HostNic;
 import types.IscsiDetails;
-import types.NetworkLabel;
 import types.NetworkAttachment;
+import types.NetworkLabel;
 import types.PowerManagement;
 import types.Ssh;
 import types.StorageDomain;
 
+/**
+ * A service to manage a host.
+ *
+ * @author Yaniv Bronheim <ybronhei@redhat.com>
+ * @date 12 Dec 2016
+ * @status added
+ */
 @Service
 @Area("Infrastructure")
 public interface HostService extends MeasurableService {
@@ -317,8 +323,30 @@ public interface HostService extends MeasurableService {
         @In Boolean undeployHostedEngine();
     }
 
+    /**
+     * Discover iSCSI targets on the host, using the initiator details.
+     *
+     * @author Oved Ourfali <oourfali@redhat.com>
+     * @date 28 Nov 2016
+     * @status added
+     */
     interface IscsiDiscover {
+        /**
+         * The target iSCSI device.
+         *
+         * @author Oved Ourfali <oourfali@redhat.com>
+         * @date 28 Nov 2016
+         * @status added
+         */
         @In IscsiDetails iscsi();
+
+        /**
+         * The iSCSI targets.
+         *
+         * @author Oved Ourfali <oourfali@redhat.com>
+         * @date 28 Nov 2016
+         * @status added
+         */
         @Out String[] iscsiTargets();
 
         /**
@@ -327,7 +355,21 @@ public interface HostService extends MeasurableService {
         @In Boolean async();
     }
 
+    /**
+     * Login to iSCSI targets on the host, using the target details.
+     *
+     * @author Oved Ourfali <oourfali@redhat.com>
+     * @date 28 Nov 2016
+     * @status added
+     */
     interface IscsiLogin {
+        /**
+         * The target iSCSI device.
+         *
+         * @author Oved Ourfali <oourfali@redhat.com>
+         * @date 28 Nov 2016
+         * @status added
+         */
         @In IscsiDetails iscsi();
 
         /**
@@ -395,6 +437,28 @@ public interface HostService extends MeasurableService {
         @In Boolean async();
     }
 
+    /**
+     * Check if there are upgrades available for the host. If there are upgrades
+     * available an icon will be displayed next to host status icon in the webadmin.
+     * Audit log messages are also added to indicate the availability of upgrades.
+     * The upgrade can be started from the webadmin or by using the
+     * <<services/host/methods/upgrade, upgrade>> host action.
+     *
+     * @author Ravi Nori <rnori@redhat.com>
+     * @date 16 Aug 2016
+     * @status added
+     * @since 4.1
+     */
+    interface UpgradeCheck {
+    }
+
+    /**
+     * Refresh the host devices and capabilities.
+     *
+     * @author Oved Ourfali <oourfali@redhat.com>
+     * @date 28 Nov 2016
+     * @status added
+     */
     interface Refresh {
         /**
          * Indicates if the refresh should be performed asynchronously.
@@ -500,6 +564,12 @@ public interface HostService extends MeasurableService {
      *           </ip>
      *         </ip_address_assignment>
      *       </ip_address_assignments>
+     *       <dns_resolver_configuration>
+     *         <name_servers>
+     *           <name_server>1.1.1.1</name_server>
+     *           <name_server>2.2.2.2</name_server>
+     *         </name_servers>
+     *       </dns_resolver_configuration>
      *     </network_attachment>
      *   </modified_network_attachments>
      *  </action>
@@ -587,10 +657,54 @@ public interface HostService extends MeasurableService {
         @In Boolean async();
     }
 
+    /**
+     * Reference to the host permission service.
+     * Use this service to manage permissions on the host object.
+     *
+     * @author Oved Ourfali <oourfali@redhat.com>
+     * @date 28 Nov 2016
+     * @status added
+     */
     @Service AssignedPermissionsService permissions();
+
+    /**
+     * Reference to the host tags service.
+     * Use this service to manage tags on the host object.
+     *
+     * @author Oved Ourfali <oourfali@redhat.com>
+     * @date 28 Nov 2016
+     * @status added
+     */
     @Service AssignedTagsService tags();
+
+    /**
+     * Reference to the fence agents service.
+     * Use this service to manage fence and power management agents on the host object.
+     *
+     * @author Oved Ourfali <oourfali@redhat.com>
+     * @date 28 Nov 2016
+     * @status added
+     */
     @Service FenceAgentsService fenceAgents();
+
+    /**
+     * Reference to the host devices service.
+     * Use this service to view the devices of the host object.
+     *
+     * @author Oved Ourfali <oourfali@redhat.com>
+     * @date 28 Nov 2016
+     * @status added
+     */
     @Service HostDevicesService devices();
+
+    /**
+     * Reference to the host hooks service.
+     * Use this service to view the hooks available in the host object.
+     *
+     * @author Oved Ourfali <oourfali@redhat.com>
+     * @date 28 Nov 2016
+     * @status added
+     */
     @Service HostHooksService hooks();
 
     /**
@@ -601,11 +715,61 @@ public interface HostService extends MeasurableService {
      * @status added
      */
     @Service HostNicsService nics();
+
+    /**
+     * Reference to the service that manage NUMA nodes for the host.
+     *
+     * @author Yaniv Bronheim <ybronhei@redhat.com>
+     * @date 12 Dec 2016
+     * @status added
+     */
     @Service HostNumaNodesService numaNodes();
+
+    /**
+     * Reference to the service that manage hosts storage.
+     *
+     * @author Yaniv Bronheim <ybronhei@redhat.com>
+     * @date 12 Dec 2016
+     * @status added
+     */
     @Service HostStorageService storage();
+
+    /**
+     * Reference to the service that can show the applicable errata available on the host.
+     * This information is taken from Katello.
+     *
+     * @author Oved Ourfali <oourfali@redhat.com>
+     * @date 28 Nov 2016
+     * @status added
+     */
     @Service KatelloErrataService katelloErrata();
+
+    /**
+     * Reference to the network attachments service. You can use this service to attach
+     * Logical networks to host interfaces.
+     *
+     * @author Oved Ourfali <oourfali@redhat.com>
+     * @date 28 Nov 2016
+     * @status added
+     */
     @Service NetworkAttachmentsService networkAttachments();
+
+    /**
+     * Reference to storage connection extensions.
+     *
+     * @author Yaniv Bronheim <ybronhei@redhat.com>
+     * @date 12 Dec 2016
+     * @status added
+     */
     @Service StorageServerConnectionExtensionsService storageConnectionExtensions();
+
+    /**
+     * Reference to unmanaged networks.
+     *
+     * @author Yaniv Bronheim <ybronhei@redhat.com>
+     * @date 12 Dec 2016
+     * @status added
+     */
     @Service UnmanagedNetworksService unmanagedNetworks();
 
     /**
