@@ -180,15 +180,9 @@ public class ClusterServiceImpl extends ServiceImpl implements ClusterService {
             }
             
             HttpResponse response = getConnection().send(request);
-            if (response.getStatusLine().getStatusCode() == 200) {
-                Action action = checkAction(response);
-                EntityUtils.consumeQuietly(response.getEntity());
-                return new ResetEmulatedMachineResponseImpl();
-            }
-            else {
-                checkFault(response);
-                return null;
-            }
+            Action action = checkAction(response);
+            EntityUtils.consumeQuietly(response.getEntity());
+            return new ResetEmulatedMachineResponseImpl();
         }
         
     }
