@@ -48,8 +48,10 @@ import org.ovirt.engine.sdk4.types.StorageDomain;
 import org.ovirt.engine.sdk4.types.Template;
 import org.ovirt.engine.sdk4.types.Ticket;
 import org.ovirt.engine.sdk4.types.Vm;
+import org.ovirt.engine.sdk4.types.VnicProfileMapping;
 
 public class ActionBuilder {
+    private Boolean allowPartialImport;
     private Boolean async;
     private List<GlusterBrick> bricks;
     private List<Certificate> certificates;
@@ -93,6 +95,8 @@ public class ActionBuilder {
     private PowerManagement powerManagement;
     private ProxyTicket proxyTicket;
     private String reason;
+    private Boolean reassignBadMacs;
+    private String remoteViewerConnectionFile;
     private List<HostNic> removedBonds;
     private List<NetworkLabel> removedLabels;
     private List<NetworkAttachment> removedNetworkAttachments;
@@ -114,6 +118,18 @@ public class ActionBuilder {
     private Boolean useSysprep;
     private HostNicVirtualFunctionsConfiguration virtualFunctionsConfiguration;
     private Vm vm;
+    private List<VnicProfileMapping> vnicProfileMappings;
+    
+    public ActionBuilder allowPartialImport(boolean newAllowPartialImport) {
+        allowPartialImport = Boolean.valueOf(newAllowPartialImport);
+        return this;
+    }
+    
+    public ActionBuilder allowPartialImport(Boolean newAllowPartialImport) {
+        allowPartialImport = newAllowPartialImport;
+        return this;
+    }
+    
     
     public ActionBuilder async(boolean newAsync) {
         async = Boolean.valueOf(newAsync);
@@ -813,6 +829,23 @@ public class ActionBuilder {
     }
     
     
+    public ActionBuilder reassignBadMacs(boolean newReassignBadMacs) {
+        reassignBadMacs = Boolean.valueOf(newReassignBadMacs);
+        return this;
+    }
+    
+    public ActionBuilder reassignBadMacs(Boolean newReassignBadMacs) {
+        reassignBadMacs = newReassignBadMacs;
+        return this;
+    }
+    
+    
+    public ActionBuilder remoteViewerConnectionFile(String newRemoteViewerConnectionFile) {
+        remoteViewerConnectionFile = newRemoteViewerConnectionFile;
+        return this;
+    }
+    
+    
     public ActionBuilder removedBonds(List<HostNic> newRemovedBonds) {
         if (newRemovedBonds != null) {
             if (removedBonds == null) {
@@ -1184,8 +1217,44 @@ public class ActionBuilder {
     }
     
     
+    public ActionBuilder vnicProfileMappings(List<VnicProfileMapping> newVnicProfileMappings) {
+        if (newVnicProfileMappings != null) {
+            if (vnicProfileMappings == null) {
+                vnicProfileMappings = new ArrayList<>(newVnicProfileMappings);
+            }
+            else {
+                vnicProfileMappings.addAll(newVnicProfileMappings);
+            }
+        }
+        return this;
+    }
+    
+    public ActionBuilder vnicProfileMappings(VnicProfileMapping... newVnicProfileMappings) {
+        if (newVnicProfileMappings != null) {
+            if (vnicProfileMappings == null) {
+                vnicProfileMappings = new ArrayList<>(newVnicProfileMappings.length);
+            }
+            Collections.addAll(vnicProfileMappings, newVnicProfileMappings);
+        }
+        return this;
+    }
+    
+    public ActionBuilder vnicProfileMappings(VnicProfileMappingBuilder... newVnicProfileMappings) {
+        if (newVnicProfileMappings != null) {
+            if (vnicProfileMappings == null) {
+                vnicProfileMappings = new ArrayList<>(newVnicProfileMappings.length);
+            }
+            for (VnicProfileMappingBuilder builder : newVnicProfileMappings) {
+                vnicProfileMappings.add(builder.build());
+            }
+        }
+        return this;
+    }
+    
+    
     public Action build() {
         ActionContainer container = new ActionContainer();
+        container.allowPartialImport(allowPartialImport);
         container.async(async);
         container.bricks(bricks);
         container.certificates(certificates);
@@ -1229,6 +1298,8 @@ public class ActionBuilder {
         container.powerManagement(powerManagement);
         container.proxyTicket(proxyTicket);
         container.reason(reason);
+        container.reassignBadMacs(reassignBadMacs);
+        container.remoteViewerConnectionFile(remoteViewerConnectionFile);
         container.removedBonds(removedBonds);
         container.removedLabels(removedLabels);
         container.removedNetworkAttachments(removedNetworkAttachments);
@@ -1250,6 +1321,7 @@ public class ActionBuilder {
         container.useSysprep(useSysprep);
         container.virtualFunctionsConfiguration(virtualFunctionsConfiguration);
         container.vm(vm);
+        container.vnicProfileMappings(vnicProfileMappings);
         return container;
     }
 }
