@@ -16,15 +16,18 @@ limitations under the License.
 package org.ovirt.engine.sdk4.services;
 
 import java.io.IOException;
+import java.util.List;
 import org.ovirt.engine.sdk4.Request;
 import org.ovirt.engine.sdk4.Response;
 import org.ovirt.engine.sdk4.Service;
 import org.ovirt.engine.sdk4.builders.ClusterBuilder;
 import org.ovirt.engine.sdk4.builders.StorageDomainBuilder;
 import org.ovirt.engine.sdk4.builders.VmBuilder;
+import org.ovirt.engine.sdk4.builders.VnicProfileMappingBuilder;
 import org.ovirt.engine.sdk4.types.Cluster;
 import org.ovirt.engine.sdk4.types.StorageDomain;
 import org.ovirt.engine.sdk4.types.Vm;
+import org.ovirt.engine.sdk4.types.VnicProfileMapping;
 
 public interface StorageDomainVmService extends Service {
     public interface GetRequest extends Request<GetRequest, GetResponse> {
@@ -124,10 +127,28 @@ public interface StorageDomainVmService extends Service {
          * default value is `false`.
          */
         ImportRequest collapseSnapshots(Boolean collapseSnapshots);
+        /**
+         * Indicates if the problematic MAC addresses should be re-assigned during the import process by the engine.
+         * 
+         * A MAC address would be considered as a problematic one if one of the following is true:
+         * 
+         * - It conflicts with a MAC address that is already allocated to a virtual machine in the target environment.
+         * - It's out of the range of the target MAC address pool.
+         */
+        ImportRequest reassignBadMacs(Boolean reassignBadMacs);
         ImportRequest storageDomain(StorageDomain storageDomain);
         ImportRequest storageDomain(StorageDomainBuilder storageDomain);
         ImportRequest vm(Vm vm);
         ImportRequest vm(VmBuilder vm);
+        ImportRequest vnicProfileMappings(List<VnicProfileMapping> vnicProfileMappings);
+        /**
+         * Mapping rules for virtual NIC profiles that will be applied during the import process.
+         */
+        ImportRequest vnicProfileMappings(VnicProfileMapping... vnicProfileMappings);
+        /**
+         * Mapping rules for virtual NIC profiles that will be applied during the import process.
+         */
+        ImportRequest vnicProfileMappings(VnicProfileMappingBuilder... vnicProfileMappings);
     }
     
     /**
@@ -258,6 +279,15 @@ public interface StorageDomainVmService extends Service {
     ImportRequest import_();
     
     public interface RegisterRequest extends Request<RegisterRequest, RegisterResponse> {
+        /**
+         * Indicates whether a virtual machine is allowed to be registered with only some of its disks.
+         * 
+         * If this flag is `true`, the engine will not fail in the validation process if an image is not found, but
+         * instead it will allow the virtual machine to be registered without the missing disks. This is mainly used
+         * during registration of a virtual machine when some of the storage domains are not available. The default
+         * value is `false`.
+         */
+        RegisterRequest allowPartialImport(Boolean allowPartialImport);
         /**
          * Indicates if the registration should be performed asynchronously.
          */
