@@ -133,6 +133,51 @@ public interface VmsService extends Service {
      * </vm>
      * ----
      * 
+     * It is possible to specify additional virtual machine parameters in the XML description, e.g. a virtual machine
+     * of `desktop` type, with 2 GiB of RAM and additional description can be added sending a request body like the
+     * following:
+     * 
+     * [source,xml]
+     * ----
+     * <vm>
+     *   <name>myvm</name>
+     *   <description>My Desktop Virtual Machine</description>
+     *   <type>desktop</type>
+     *   <memory>2147483648</memory>
+     *   ...
+     * </vm>
+     * ----
+     * 
+     * A bootable CDROM device can be set like this:
+     * 
+     * [source,xml]
+     * ----
+     * <vm>
+     *   ...
+     *   <os>
+     *     <boot dev="cdrom"/>
+     *   </os>
+     * </vm>
+     * ----
+     * 
+     * In order to boot from CDROM, you first need to insert a disk, as described in the
+     * <<services/vm_cdrom, CDROM service>>. Then booting from that CDROM can be specified using the `os.boot.devices`
+     * attribute:
+     * 
+     * [source,xml]
+     * ----
+     * <vm>
+     *   ...
+     *   <os>
+     *     <boot>
+     *       <devices>
+     *         <device>cdrom</device>
+     *       </devices>
+     *     </boot>
+     *   </os>
+     * </vm>
+     * ----
+     * 
      * In all cases the name or identifier of the cluster where the virtual machine will be created is mandatory.
      */
     public interface AddRequest extends Request<AddRequest, AddResponse> {
@@ -309,6 +354,51 @@ public interface VmsService extends Service {
      * </vm>
      * ----
      * 
+     * It is possible to specify additional virtual machine parameters in the XML description, e.g. a virtual machine
+     * of `desktop` type, with 2 GiB of RAM and additional description can be added sending a request body like the
+     * following:
+     * 
+     * [source,xml]
+     * ----
+     * <vm>
+     *   <name>myvm</name>
+     *   <description>My Desktop Virtual Machine</description>
+     *   <type>desktop</type>
+     *   <memory>2147483648</memory>
+     *   ...
+     * </vm>
+     * ----
+     * 
+     * A bootable CDROM device can be set like this:
+     * 
+     * [source,xml]
+     * ----
+     * <vm>
+     *   ...
+     *   <os>
+     *     <boot dev="cdrom"/>
+     *   </os>
+     * </vm>
+     * ----
+     * 
+     * In order to boot from CDROM, you first need to insert a disk, as described in the
+     * <<services/vm_cdrom, CDROM service>>. Then booting from that CDROM can be specified using the `os.boot.devices`
+     * attribute:
+     * 
+     * [source,xml]
+     * ----
+     * <vm>
+     *   ...
+     *   <os>
+     *     <boot>
+     *       <devices>
+     *         <device>cdrom</device>
+     *       </devices>
+     *     </boot>
+     *   </os>
+     * </vm>
+     * ----
+     * 
      * In all cases the name or identifier of the cluster where the virtual machine will be created is mandatory.
      */
     public interface AddResponse extends Response {
@@ -423,11 +513,77 @@ public interface VmsService extends Service {
      * </vm>
      * ----
      * 
+     * It is possible to specify additional virtual machine parameters in the XML description, e.g. a virtual machine
+     * of `desktop` type, with 2 GiB of RAM and additional description can be added sending a request body like the
+     * following:
+     * 
+     * [source,xml]
+     * ----
+     * <vm>
+     *   <name>myvm</name>
+     *   <description>My Desktop Virtual Machine</description>
+     *   <type>desktop</type>
+     *   <memory>2147483648</memory>
+     *   ...
+     * </vm>
+     * ----
+     * 
+     * A bootable CDROM device can be set like this:
+     * 
+     * [source,xml]
+     * ----
+     * <vm>
+     *   ...
+     *   <os>
+     *     <boot dev="cdrom"/>
+     *   </os>
+     * </vm>
+     * ----
+     * 
+     * In order to boot from CDROM, you first need to insert a disk, as described in the
+     * <<services/vm_cdrom, CDROM service>>. Then booting from that CDROM can be specified using the `os.boot.devices`
+     * attribute:
+     * 
+     * [source,xml]
+     * ----
+     * <vm>
+     *   ...
+     *   <os>
+     *     <boot>
+     *       <devices>
+     *         <device>cdrom</device>
+     *       </devices>
+     *     </boot>
+     *   </os>
+     * </vm>
+     * ----
+     * 
      * In all cases the name or identifier of the cluster where the virtual machine will be created is mandatory.
      */
     AddRequest add();
     
     public interface ListRequest extends Request<ListRequest, ListResponse> {
+        /**
+         * Indicates if all the attributes of the virtual machines should be included in the response.
+         * 
+         * By default the following attributes are excluded:
+         * 
+         * - `console`
+         * - `initialization.configuration.data` - The OVF document describing the virtual machine.
+         * - `rng_source`
+         * - `soundcard`
+         * - `virtio_scsi`
+         * 
+         * For example, to retrieve the complete representation of the virtual machines send a request like this:
+         * 
+         * ....
+         * GET /ovirt-engine/api/vms?all_content=true
+         * ....
+         * 
+         * NOTE: The reason for not including these attributes is performance: they are seldom used and they require
+         * additional queries to the database. So try to use the this parameter only when it is really needed.
+         */
+        ListRequest allContent(Boolean allContent);
         /**
          * Indicates if the search performed using the `search` parameter should be performed taking case into
          * account. The default value is `true`, which means that case is taken into account. If you want to search
